{
    "$graph": [
        {
            "class": "Workflow",
            "label": "umi per-lane alignment subworkflow",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#main/bam"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#main/read_structure"
                },
                {
                    "type": "string",
                    "id": "#main/reference"
                }
            ],
            "steps": [
                {
                    "run": "#umi_align.cwl",
                    "in": [
                        {
                            "source": "#main/mark_illumina_adapters/marked_bam",
                            "id": "#main/align/bam"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/align/reference"
                        }
                    ],
                    "out": [
                        "#main/align/aligned_bam"
                    ],
                    "id": "#main/align"
                },
                {
                    "run": "#extract_umis.cwl",
                    "in": [
                        {
                            "source": "#main/bam",
                            "id": "#main/extract_umis/bam"
                        },
                        {
                            "source": "#main/read_structure",
                            "id": "#main/extract_umis/read_structure"
                        }
                    ],
                    "out": [
                        "#main/extract_umis/umi_extracted_bam"
                    ],
                    "id": "#main/extract_umis"
                },
                {
                    "run": "#mark_illumina_adapters.cwl",
                    "in": [
                        {
                            "source": "#main/extract_umis/umi_extracted_bam",
                            "id": "#main/mark_illumina_adapters/bam"
                        }
                    ],
                    "out": [
                        "#main/mark_illumina_adapters/marked_bam",
                        "#main/mark_illumina_adapters/metrics"
                    ],
                    "id": "#main/mark_illumina_adapters"
                }
            ],
            "id": "#main",
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/mark_illumina_adapters/metrics",
                    "id": "#main/adapter_metrics"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "outputSource": "#main/align/aligned_bam",
                    "id": "#main/aligned_bam"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "extract umis from bam",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx4g",
                "-jar",
                "/opt/fgbio-0.5.0.jar",
                "ExtractUmisFromBam"
            ],
            "arguments": [
                "--molecular-index-tags",
                "ZA",
                "ZB",
                "--single-tag",
                "RX",
                "--output",
                {
                    "valueFrom": "$(runtime.outdir)/umi_extracted.bam"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 6000,
                    "tmpdirMin": 25000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/dna-alignment"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--input"
                    },
                    "id": "#extract_umis.cwl/bam"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "inputBinding": {
                        "prefix": "--read-structure"
                    },
                    "id": "#extract_umis.cwl/read_structure"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "umi_extracted.bam"
                    },
                    "id": "#extract_umis.cwl/umi_extracted_bam"
                }
            ],
            "id": "#extract_umis.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "fastq to bam",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx4g",
                "-jar",
                "/opt/picard/picard.jar",
                "MarkIlluminaAdapters"
            ],
            "arguments": [
                "OUTPUT=",
                {
                    "valueFrom": "$(runtime.outdir)/marked.bam"
                },
                "METRICS=",
                {
                    "valueFrom": "$(runtime.outdir)/adapter_metrics.txt"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 6000,
                    "tmpdirMin": 25000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/dna-alignment"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "INPUT=",
                        "position": 1
                    },
                    "id": "#mark_illumina_adapters.cwl/bam"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "marked.bam"
                    },
                    "id": "#mark_illumina_adapters.cwl/marked_bam"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "adapter_metrics.txt"
                    },
                    "id": "#mark_illumina_adapters.cwl/metrics"
                }
            ],
            "id": "#mark_illumina_adapters.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "umi alignment",
            "baseCommand": [
                "/bin/bash",
                "/usr/bin/umi_alignment.sh"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 16000,
                    "coresMin": 8
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/dna-alignment"
                }
            ],
            "arguments": [
                {
                    "position": 3,
                    "valueFrom": "$(runtime.cores)"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#umi_align.cwl/bam"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#umi_align.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "outputBinding": {
                        "glob": "aligned.bam"
                    },
                    "id": "#umi_align.cwl/aligned_bam"
                }
            ],
            "id": "#umi_align.cwl"
        }
    ],
    "cwlVersion": "v1.0"
}
